.. image:: https://badge.fury.io/py/labml-nn.svg
    :target: https://badge.fury.io/py/labml-nn
.. image:: https://pepy.tech/badge/labml-nn
    :target: https://pepy.tech/project/labml-nn

`LabML Neural Networks <http://lab-ml.com/labml_nn/index.html>`_
================================================================

This is a collection of simple PyTorch implementation of various neural network architectures and layers. We will keep adding to this.

Transformers
------------

`Transformers module  <http://lab-ml.com/labml_nn/transformers>`_ contains implementations for
`multi-headed attention <http://lab-ml.com/labml_nn/transformers/mha.html>`_
and
`relative multi-headed attention <http://lab-ml.com/labml_nn/transformers/relative_mha.html>`_.

Recurrent Highway Networks
--------------------------

This is the implementation for `Recurrent Highway Networks <http://lab-ml.com/labml_nn/recurrent_highway_networks>`_.


LSTM
----

This is the implementation for `LSTMs <http://lab-ml.com/labml_nn/lstm>`_.

✅ Please create a Github issue if there's something you'ld like to see implemented here.

Installation
------------

.. code-block:: console

    pip install labml_nn

Links
-----

`💬 Slack workspace for discussions <https://join.slack.com/t/labforml/shared_invite/zt-egj9zvq9-Dl3hhZqobexgT7aVKnD14g/>`_

`📗 Documentation <http://lab-ml.com/>`_

`📑 Articles & Tutorials <https://medium.com/@labml/>`_

`👨‍🏫 Samples <https://github.com/lab-ml/samples>`_


Citing LabML
------------

If you use LabML for academic research, please cite the library using the following BibTeX entry.

.. code-block:: bibtex

	@misc{labml,
	 author = {Varuna Jayasiri, Nipun Wijerathne},
	 title = {LabML: A library to organize machine learning experiments},
	 year = {2020},
	 url = {https://lab-ml.com/},
	}

